Crate bevy_bundletree
bevy_
bundletree
0.18.0
All Items
Crate Items
Structs
Crate
bevy_
bundletree
Structs

Child
Bundle
A component that, when added to an entity, will add a child entity with the given bundle.
Child
Bundles
A component that, when added to an entity, will add a child entity with the given bundle.